# -*- coding: utf-8 -*-
from amplify.agent.context import context
from amplify.agent.containers.abstract import AbstractObject
from amplify.agent.containers.system.collectors.meta import SystemMetaCollector
from amplify.agent.containers.system.collectors.metrics import SystemMetricsCollector
from amplify.agent.eventd import INFO


__author__ = "Mike Belov"
__copyright__ = "Copyright (C) 2015, Nginx Inc. All rights reserved."
__credits__ = ["Mike Belov", "Andrei Belov", "Ivan Poluyanov", "Oleg Mamontov", "Andrew Alexeev", "Grant Hulegaard"]
__license__ = ""
__maintainer__ = "Mike Belov"
__email__ = "dedm@nginx.com"



class SystemObject(AbstractObject):
    type = 'system'

    def __init__(self, **kwargs):
        super(SystemObject, self).__init__(**kwargs)

        self.uuid = self.data['uuid']
        self.hostname = self.data['hostname']
        self.collectors = [
            SystemMetaCollector(object=self, interval=self.intervals['meta']),
            SystemMetricsCollector(object=self, interval=self.intervals['metrics'])
        ]

    def start(self):
        if not self.running:
            # Fire agent started event.
            self.eventd.event(
                level=INFO,
                message='agent started, version: %s' % context.version
            )
        super(SystemObject, self).start()

    def stop(self, *args, **kwargs):
        # Fire agent stopped event.
        self.eventd.event(
            level=INFO,
            message='agent stopped, version: %s' % context.version
        )
        super(SystemObject, self).stop(*args, **kwargs)
